==> nuntio_hera-0.0.14.tar.gz: lib/hera_ui/hera_ui.dart <==
import 'dart:async';
import 'package:flutter/cupertino.dart';
import 'package:connectivity_plus/connectivity_plus.dart';
import 'package:flutter/material.dart';
import 'package:flutter/scheduler.dart';
import 'package:flutter_svg/flutter_svg.dart';
import '../../hera.pb.dart';
import '../../hera.pbenum.dart';
import '../hera/hera.dart';
import '../hera/models/auth.dart';
import 'components/nuntio_indicator.dart';
import 'AuthPage/LoginPage/login_page.dart';
import 'NoConnection/no_connection.dart';
import 'models.dart';

class HeraUI extends StatefulWidget {
  HeraUI({
    Key? key,
    required this.child,
    HeraColor? heraColor,
    HeraTextStyle? heraTextStyle,
    HeraStyle? heraStyle,
    HeraFooter? heraFooter,
    Brightness? brightness,
    this.logo,
    this.excludeAuthMechanisms,
    this.heraText,
    this.padding,
  }) {
    this.brightness =
        brightness ?? SchedulerBinding.instance.window.platformBrightness;
    this.heraStyle = heraStyle ?? HeraStyle();
    this.heraStyle.build(this.brightness);
    this.heraColor = heraColor ?? HeraColor();
    this.heraColor.build(this.brightness);
    this.heraTextStyle = heraTextStyle ?? HeraTextStyle();
    this.heraTextStyle.build(this.brightness);
    this.heraFooter = heraFooter ?? HeraFooter();
  }

  // authentication
  final List<LoginType>? excludeAuthMechanisms;

  // style and text config
  final HeraText? heraText;
  late final HeraStyle heraStyle;
  late final HeraColor heraColor;
  late final HeraTextStyle heraTextStyle;
  late final HeraFooter heraFooter;

  // general
  final Widget child;
  final Widget? logo;
  final EdgeInsetsGeometry? padding;
  late final Brightness brightness;

  // on authenticated go to child;
  @override
  State<HeraUI> createState() => _HeraUIState();
}

class _HeraUIState extends State<HeraUI> {
  // init
  AuthState authState = AuthState.loading;
  late Future<void> initializeNuntioUIFuture;
  late Config _config;
  late HeraText heraText;
  late TextInputType identifierInputType;

  Future<void> initializeAuthStatus() async {
    var connectivityResult = await (Connectivity().checkConnectivity());
    if (connectivityResult == ConnectivityResult.none) {
      //  no data connection
      setState(() {
        authState = AuthState.noConnection;
      });
      return;
    }
    bool authenticated = await Hera.isAuthenticated();
    if (authenticated) {
      setState(() {
        authState = AuthState.authenticated;
      });
    } else {
      _config = await Hera.getConfig();
      // remove excluded login mechanisms
      _config.supportedLoginMechanisms.removeWhere(
          (e) => widget.excludeAuthMechanisms?.contains(e) == true);
      _config.oidcProviders.removeWhere((e) => e.enabled == false);
      // if oidc is not enabled remove
      heraText = widget.heraText ?? HeraText();
      heraText.build(supportedAuthMechanisms: _config.supportedLoginMechanisms);
      TextInputType _identifierInputType = TextInputType.text;
      if (_config.supportedLoginMechanisms
              .contains(LoginType.USERNAME_PASSWORD) ||
          (_config.supportedLoginMechanisms
                  .contains(LoginType.EMAIL_PASSWORD) &&
              _config.supportedLoginMechanisms
                  .contains(LoginType.PHONE_PASSWORD))) {
        _identifierInputType = TextInputType.text;
      } else if (_config.supportedLoginMechanisms
          .contains(LoginType.PHONE_PASSWORD)) {
        _identifierInputType == TextInputType.phone;
      } else if (_config.supportedLoginMechanisms
          .contains(LoginType.EMAIL_PASSWORD)) {
        _identifierInputType == TextInputType.emailAddress;
      }
      setState(() {
        identifierInputType = _identifierInputType;
        authState = AuthState.notAuthenticated;
      });
    }
    debugPrint(authState.toString());
  }

  @override
  void initState() {
    Hera.onLogout = () {
      setState(() {
        authState = AuthState.notAuthenticated;
      });
    };
    initializeAuthStatus();
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    return CupertinoApp(
      localizationsDelegates: const [
        DefaultMaterialLocalizations.delegate,
        DefaultCupertinoLocalizations.delegate,
        DefaultWidgetsLocalizations.delegate,
      ],
      debugShowCheckedModeBanner: false,
      theme: CupertinoThemeData(
        primaryColor: widget.heraColor.primaryColor,
      ),
      home: Builder(builder: (context) {
        switch (authState) {
          case AuthState.loading:
            return Center(
                child: NuntioIndicator(
              size: 28,
              color: widget.brightness == Brightness.light
                  ? CupertinoColors.black
                  : CupertinoColors.white,
            ));
          case AuthState.authenticated:
            return widget.child;
          case AuthState.notAuthenticated:
            return LoginPage(
              padding: widget.padding,
              supportedAuthMechanisms: _config.supportedLoginMechanisms,
              identifierInputType: identifierInputType,
              brightness: widget.brightness,
              nuntioFooter: widget.heraFooter,
              logo: widget.logo ??
                  (_config.logo.isNotEmpty
                      ? Padding(
                          padding: const EdgeInsets.only(bottom: 10),
                          child: SvgPicture.network(
                            _config.logo,
                            height: widget.heraStyle.logoHeight,
                            placeholderBuilder: (context) {
                              return Image(
                                  image: NetworkImage(_config.logo),
                                  height: widget.heraStyle.logoHeight,
                                  errorBuilder: (context, o, stackTrace) {
                                    return NuntioIndicator();
                                  });
                            },
                          ),
                        )
                      : SizedBox()),
              nuntioText: heraText,
              nuntioColor: widget.heraColor,
              nuntioStyle: widget.heraStyle,
              nuntioTextStyle: widget.heraTextStyle,
              onAuth: (BuildContext buildContext) {
                Hera.isAuthenticated().then((value) {
                  print("is authenticated");
                  print(value);
                  print("is authenticated");
                  setState(() {
                    authState = value
                        ? AuthState.authenticated
                        : AuthState.notAuthenticated;
                  });
                });
              },
              background: widget.heraStyle.background,
              config: _config,
            );
          default:
            return NoConnection(
              background: widget.heraStyle.background,
              logo: widget.logo ??
                  Image(
                    image: NetworkImage(_config.logo),
                    height: widget.heraStyle.logoHeight,
                  ),
              nuntioText: heraText,
              nuntioTextStyle: widget.heraTextStyle,
              nuntioColor: widget.heraColor,
            );
        }
      }),
    );
  }
}

==> nuntio_hera-0.0.16.tar.gz: lib/hera_ui/hera_ui.dart <==
import 'dart:async';
import 'package:flutter/cupertino.dart';
import 'package:connectivity_plus/connectivity_plus.dart';
import 'package:flutter/material.dart';
import 'package:flutter/scheduler.dart';
import 'package:flutter_svg/flutter_svg.dart';
import '../../hera.pb.dart';
import '../../hera.pbenum.dart';
import '../hera/hera.dart';
import '../hera/models/auth.dart';
import 'components/nuntio_indicator.dart';
import 'AuthPage/LoginPage/login_page.dart';
import 'NoConnection/no_connection.dart';
import 'models.dart';

class HeraUI extends StatefulWidget {
  HeraUI({
    Key? key,
    required this.child,
    HeraColor? heraColor,
    HeraTextStyle? heraTextStyle,
    HeraStyle? heraStyle,
    HeraFooter? heraFooter,
    Brightness? brightness,
    this.logo,
    this.excludeAuthMechanisms,
    this.heraText,
    this.padding,
  }) {
    this.brightness =
        brightness ?? SchedulerBinding.instance.window.platformBrightness;
    this.heraStyle = heraStyle ?? HeraStyle();
    this.heraStyle.build(this.brightness);
    this.heraColor = heraColor ?? HeraColor();
    this.heraColor.build(this.brightness);
    this.heraTextStyle = heraTextStyle ?? HeraTextStyle();
    this.heraTextStyle.build(this.brightness);
    this.heraFooter = heraFooter ?? HeraFooter();
  }

  // authentication
  final List<LoginType>? excludeAuthMechanisms;

  // style and text config
  final HeraText? heraText;
  late final HeraStyle heraStyle;
  late final HeraColor heraColor;
  late final HeraTextStyle heraTextStyle;
  late final HeraFooter heraFooter;

  // general
  final Widget child;
  final Widget? logo;
  final EdgeInsetsGeometry? padding;
  late final Brightness brightness;

  // on authenticated go to child;
  @override
  State<HeraUI> createState() => _HeraUIState();
}

class _HeraUIState extends State<HeraUI> {
  // init
  AuthState authState = AuthState.loading;
  late Future<void> initializeNuntioUIFuture;
  late Config _config;
  late HeraText heraText;
  late TextInputType identifierInputType;

  Future<void> initializeAuthStatus() async {
    var connectivityResult = await (Connectivity().checkConnectivity());
    if (connectivityResult == ConnectivityResult.none) {
      //  no data connection
      setState(() {
        authState = AuthState.noConnection;
      });
      return;
    }
    bool authenticated = await Hera.isAuthenticated();
    if (authenticated) {
      setState(() {
        authState = AuthState.authenticated;
      });
    } else {
      _config = await Hera.getConfig();
      // remove excluded login mechanisms
      _config.supportedLoginMechanisms.removeWhere(
          (e) => widget.excludeAuthMechanisms?.contains(e) == true);
      _config.oidcProviders.removeWhere((k, v) => v.enabled == false);
      // if oidc is not enabled remove
      heraText = widget.heraText ?? HeraText();
      heraText.build(supportedAuthMechanisms: _config.supportedLoginMechanisms);
      TextInputType _identifierInputType = TextInputType.text;
      if (_config.supportedLoginMechanisms
              .contains(LoginType.USERNAME_PASSWORD) ||
          (_config.supportedLoginMechanisms
                  .contains(LoginType.EMAIL_PASSWORD) &&
              _config.supportedLoginMechanisms
                  .contains(LoginType.PHONE_PASSWORD))) {
        _identifierInputType = TextInputType.text;
      } else if (_config.supportedLoginMechanisms
          .contains(LoginType.PHONE_PASSWORD)) {
        _identifierInputType == TextInputType.phone;
      } else if (_config.supportedLoginMechanisms
          .contains(LoginType.EMAIL_PASSWORD)) {
        _identifierInputType == TextInputType.emailAddress;
      }
      setState(() {
        identifierInputType = _identifierInputType;
        authState = AuthState.notAuthenticated;
      });
    }
    debugPrint(authState.toString());
  }

  @override
  void initState() {
    Hera.onLogout = () {
      setState(() {
        authState = AuthState.notAuthenticated;
      });
    };
    initializeAuthStatus();
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    return CupertinoApp(
      localizationsDelegates: const [
        DefaultMaterialLocalizations.delegate,
        DefaultCupertinoLocalizations.delegate,
        DefaultWidgetsLocalizations.delegate,
      ],
      debugShowCheckedModeBanner: false,
      theme: CupertinoThemeData(
        primaryColor: widget.heraColor.primaryColor,
      ),
      home: Builder(builder: (context) {
        switch (authState) {
          case AuthState.loading:
            return Center(
                child: NuntioIndicator(
              size: 28,
              color: widget.brightness == Brightness.light
                  ? CupertinoColors.black
                  : CupertinoColors.white,
            ));
          case AuthState.authenticated:
            return widget.child;
          case AuthState.notAuthenticated:
            return LoginPage(
              padding: widget.padding,
              supportedAuthMechanisms: _config.supportedLoginMechanisms,
              identifierInputType: identifierInputType,
              brightness: widget.brightness,
              nuntioFooter: widget.heraFooter,
              logo: widget.logo ??
                  (_config.logo.isNotEmpty
                      ? Padding(
                          padding: const EdgeInsets.only(bottom: 10),
                          child: SvgPicture.network(
                            _config.logo,
                            height: widget.heraStyle.logoHeight,
                            placeholderBuilder: (context) {
                              return Image(
                                  image: NetworkImage(_config.logo),
                                  height: widget.heraStyle.logoHeight,
                                  errorBuilder: (context, o, stackTrace) {
                                    return NuntioIndicator();
                                  });
                            },
                          ),
                        )
                      : SizedBox()),
              nuntioText: heraText,
              nuntioColor: widget.heraColor,
              nuntioStyle: widget.heraStyle,
              nuntioTextStyle: widget.heraTextStyle,
              onAuth: (BuildContext buildContext) {
                Hera.isAuthenticated().then((value) {
                  print("is authenticated");
                  print(value);
                  print("is authenticated");
                  setState(() {
                    authState = value
                        ? AuthState.authenticated
                        : AuthState.notAuthenticated;
                  });
                });
              },
              background: widget.heraStyle.background,
              config: _config,
            );
          default:
            return NoConnection(
              background: widget.heraStyle.background,
              logo: widget.logo ??
                  Image(
                    image: NetworkImage(_config.logo),
                    height: widget.heraStyle.logoHeight,
                  ),
              nuntioText: heraText,
              nuntioTextStyle: widget.heraTextStyle,
              nuntioColor: widget.heraColor,
            );
        }
      }),
    );
  }
}
